#!/bin/sh
#
######################################################################
# Usage:
#      ImportAgentTEPSBefore <installhome> 
# Result:
#      0   Successful
#      >0  Failed
####################################################################
cd ${KFW_BIN_DIR}
export KFW_HOME=${KFW_BIN_DIR}/..

export CANDLEHOME=$1

# simple verification if the candlehome
if [ ! -d "${CANDLEHOME}" ] ; then 
	exit 2
fi

# log the execution
echo "ImportAgentTEPSBefore started with $* ">>${CANDLEHOME}/logs/ImportAgentTEPSBefore.log


# check targets
if [ ! -d ${KFW_HOME} ]; then
	echo "ERROR: target directory ${KFW_HOME} not found" >>${CANDLEHOME}/logs/ImportAgentTEPSBefore.log
	exit 2
fi 
echo "target directory ${KFW_HOME} found" >>${CANDLEHOME}/logs/ImportAgentTEPSBefore.log

if [ ! -d ${KFW_HOME}/../cw ]; then
	echo "ERROR: target directory ${CANDLEHOME}/../cw not found" >>${CANDLEHOME}/logs/ImportAgentTEPSBefore.log
	exit  2
fi 
echo "target directory ${CANDLEHOME}/../cw found" >>${CANDLEHOME}/logs/ImportAgentTEPSBefore.log

### do we need to enable DE ###
if [ "$2" = "" ]; then
	exit 0
fi

echo "Enabling DE" >>${CANDLEHOME}/logs/ImportAgentTEPSBefore.log
if [ -f ${KFW_BIN_DIR}/../sqllib/kfw_de_pres.sql ]; then
        echo "TEP DE already enabled" >>${CANDLEHOME}/logs/ImportAgentTEPSBefore.log
        exit 0
fi

if [ -f ${KFW_BIN_DIR}/../sqllib/kfw_de_links.sql ]; then
        echo "TEP DE already enabled" >>${CANDLEHOME}/logs/ImportAgentTEPSBefore.log
        exit 0
fi

if [ ! -f ${KFW_BIN_DIR}/../sqllib/presfile.sql ]; then
        echo "TEP DE pres file presfile.sql missing" >>${CANDLEHOME}/logs/ImportAgentTEPSBefore.log
        exit 2
fi

if [ ! -f ${KFW_BIN_DIR}/../sqllib/linksfile.sql ]; then
        echo "TEP DE links file linksfile.sql missing" >>${CANDLEHOME}/logs/ImportAgentTEPSBefore.log
        exit 2
fi

echo "============= cq.ini backup start ====================">>${CANDLEHOME}/logs/ImportAgentTEPSBefore.log
cat ${CANDLEHOME}/config/cq.ini >>${CANDLEHOME}/config/cqini.bak
echo "============= cq.ini backup end ======================">>${CANDLEHOME}/logs/ImportAgentTEPSBefore.log
grep -e "^ *KFW_AUTHORIZATION_KEY *=" ${CANDLEHOME}/config/cq.ini >>/dev/null
if [ ! "$?" = "0" ]; then
	echo "TEP new KFW_AUTHORIZATION_KEY variable in cq.ini." >>${CANDLEHOME}/logs/ImportAgentTEPSBefore.log 
	echo "KFW_AUTHORIZATION_KEY=$2" >>${CANDLEHOME}/config/cq.ini 
	if [ ! "$?" = "0" ]; then
		echo "ERROR: failed to add KFW_AUTHORIZATION_KEY to ${CANDLEHOME}/config/cq.ini" >>${CANDLEHOME}/logs/ImportAgentTEPSBefore.log
		exit 2
	fi
else
	echo "TEP replacing KFW_AUTHORIZATION_KEY variable in cq.ini." >>${CANDLEHOME}/logs/ImportAgentTEPSBefore.log 
	sed -e "s/^ *KFW_AUTHORIZATION_KEY *=.*\$/KFW_AUTHORIZATION_KEY=$2/" ${CANDLEHOME}/config/cq.ini >/tmp/cq.ini.unix
        mv /tmp/cq.ini.unix ${CANDLEHOME}/config/cq.ini
	if [ ! "$?" = "0" ]; then
		echo "ERROR: failed to modify ${CANDLEHOME}/config/cq.ini" >>${CANDLEHOME}/logs/ImportAgentTEPSBefore.log
		exit 2
	fi
fi
	

echo "============= cq.config backup start ====================">>${CANDLEHOME}/logs/ImportAgentTEPSBefore.log
cat ${CANDLEHOME}/config/cq.config >>${CANDLEHOME}/config/cqconfig.bak
echo "============= cq.config backup end ======================">>${CANDLEHOME}/logs/ImportAgentTEPSBefore.log
grep -e "^ *KFW_AUTHORIZATION_KEY *=" ${CANDLEHOME}/config/cq.config >>/dev/null
if [ ! "$?" = "0" ]; then
	echo "TEP new KFW_AUTHORIZATION_KEY variable in cq.config." >>${CANDLEHOME}/logs/ImportAgentTEPSBefore.log 
	echo "KFW_AUTHORIZATION_KEY='$2'" >>${CANDLEHOME}/config/cq.config 
	if [ ! "$?" = "0" ]; then
		echo "ERROR: failed to add KFW_AUTHORIZATION_KEY to ${CANDLEHOME}/config/cq.config" >>${CANDLEHOME}/logs/ImportAgentTEPSBefore.log
		exit 2
	fi
else
	echo "TEP replacing KFW_AUTHORIZATION_KEY variable in cq.config." >>${CANDLEHOME}/logs/ImportAgentTEPSBefore.log 
	sed -e "s/^ *KFW_AUTHORIZATION_KEY *=.*\$/KFW_AUTHORIZATION_KEY='$2'/" ${CANDLEHOME}/config/cq.config >/tmp/cq.config.unix
        mv /tmp/cq.config.unix ${CANDLEHOME}/config/cq.config
	if [ ! "$?" = "0" ]; then
		echo "ERROR: failed to modify ${CANDLEHOME}/config/cq.config" >>${CANDLEHOME}/logs/ImportAgentTEPSBefore.log
		exit 2
	fi
fi
echo "DE license set" >>${CANDLEHOME}/logs/ImportAgentTEPSBefore.log

mv ${KFW_BIN_DIR}/../sqllib/presfile.sql ${KFW_BIN_DIR}/../sqllib/kfw_de_pres.sql
if [ ! "$?" = "0" ]; then
        echo "ERROR: failed to rename the de pres file" >>${CANDLEHOME}/logs/ImportAgentTEPSBefore.log
        exit 2
fi
echo "DE pres file ready" >>${CANDLEHOME}/logs/ImportAgentTEPSBefore.log

mv ${KFW_BIN_DIR}/../sqllib/linksfile.sql ${KFW_BIN_DIR}/../sqllib/kfw_de_links.sql
if [ ! "$?" = "0" ]; then
        echo "ERROR: failed to rename the de links file" >>${CANDLEHOME}/logs/ImportAgentTEPSBefore.log
        exit 2
fi
echo "DE links file ready" >>${CANDLEHOME}/logs/ImportAgentTEPSBefore.log

if [ -f ${KFW_BIN_DIR}/../sqllib/kfw_xe_pres.sql ]; then
	mv ${KFW_BIN_DIR}/../sqllib/kfw_xe_pres.sql ${KFW_BIN_DIR}/../sqllib/oldpresfile.sql
	if [ ! "$?" = "0" ]; then
		echo "ERROR: failed to rename ${KFW_BIN_DIR}/../sqllib/kfw_xe_pres.sql" >>${CANDLEHOME}/logs/ImportAgentTEPSBefore.log
		exit 2
	fi
fi
echo "XE pres file renamed" >>${CANDLEHOME}/logs/ImportAgentTEPSBefore.log

if [ -f ${KFW_BIN_DIR}/../sqllib/kfw_xe_links.sql ]; then
	mv ${KFW_BIN_DIR}/../sqllib/kfw_xe_links.sql ${KFW_BIN_DIR}/../sqllib/oldlinksfile.sql
	if [ ! "$?" = "0" ]; then
		echo "ERROR: failed to rename ${KFW_BIN_DIR}/../sqllib/kfw_xe_links.sql" >>${CANDLEHOME}/logs/ImportAgentTEPSBefore.log
		exit 2
	fi
fi
echo "XE links file renamed" >>${CANDLEHOME}/logs/ImportAgentTEPSBefore.log


exit 0
