@echo off
setlocal
REM #####################################################################
REM Usage:
REM      ImportAgentTEPS <version> <source dir> <agent> <installhome>
REM Result:
REM      0   Successful
REM      >0  Failed
REM ####################################################################

set IMPORTVERSION=%1
set SOURCEDIR=%2
set AGENTNAME=%3
set CANDLE_HOME=%4
set HAVECNPS=Y
set HAVECNB=Y
set HAVEHELPSVR=Y

REM simple verification if the candlehome
if "%CANDLE_HOME%" == ""  exit 2
if NOT EXIST %CANDLE_HOME% exit 2

set PATH=%CANDLE_HOME%\CNPS;%PATH%

REM log the execution
echo ImportAgentTEPS started with %1 %2 %3 %4 %5>>%CANDLE_HOME%\CNPS\logs\ImportAgentTEPS.log


REM check version. We only support version 610 and higher
if "%IMPORTVERSION%" LSS "610" (
	echo ERROR: import of version %IMPORTVERSION% not supported>>%CANDLE_HOME%\CNPS\logs\ImportAgentTEPS.log
	exit 1
)
echo importing of version is %IMPORTVERSION%>>%CANDLE_HOME%\CNPS\logs\ImportAgentTEPS.log


REM check source
if NOT EXIST %SOURCEDIR%\TEPS (
	echo ERROR: source directory %SOURCEDIR%\TEPS not found >>%CANDLE_HOME%\CNPS\logs\ImportAgentTEPS.log
	exit 2
)
echo source directory %SOURCEDIR%\TEPS found >>%CANDLE_HOME%\CNPS\logs\ImportAgentTEPS.log

REM check targets
if NOT EXIST %CANDLE_HOME%\CNPS (
	echo ERROR: target directory %CANDLE_HOME%\CNPS not found >>%CANDLE_HOME%\CNPS\logs\ImportAgentTEPS.log
	exit 2
)
echo target directory %CANDLE_HOME%\CNPS found >>%CANDLE_HOME%\CNPS\logs\ImportAgentTEPS.log

if NOT EXIST %CANDLE_HOME%\CNB (
	echo ERROR: target directory %CANDLE_HOME%\CNB not found >>%CANDLE_HOME%\CNPS\logs\ImportAgentTEPS.log
	exit 2
)
echo target directory %CANDLE_HOME%\CNB found >>%CANDLE_HOME%\CNPS\logs\ImportAgentTEPS.log

if NOT EXIST %CANDLE_HOME%\HELPSVR (
	echo target directory %CANDLE_HOME%\HELPSVR not found >>%CANDLE_HOME%\CNPS\logs\ImportAgentTEPS.log
	set HAVEHELPSVR=N
) else (
        echo target directory %CANDLE_HOME%\HELPSVR found >>%CANDLE_HOME%\CNPS\logs\ImportAgentTEPS.log
)

REM check source
if NOT EXIST %SOURCEDIR%\TEPS\CNB (
	echo source directory %SOURCEDIR%\TEPS\CNB not found >>%CANDLE_HOME%\CNPS\logs\ImportAgentTEPS.log
	set HAVECNB=N
) else (
        echo source directory %SOURCEDIR%\TEPS\CNB found >>%CANDLE_HOME%\CNPS\logs\ImportAgentTEPS.log
)

if NOT EXIST %SOURCEDIR%\TEPS\CNPS (
	echo source directory %SOURCEDIR%\TEPS\CNPS not found >>%CANDLE_HOME%\CNPS\logs\ImportAgentTEPS.log
	set HAVECNPS=N
) else (
        echo source directory %SOURCEDIR%\TEPS\CNPS found >>%CANDLE_HOME%\CNPS\logs\ImportAgentTEPS.log
)

if NOT EXIST %SOURCEDIR%\TEPS\HELPSVR (
	echo source directory %SOURCEDIR%\TEPS\HELPSVR not found >>%CANDLE_HOME%\CNPS\logs\ImportAgentTEPS.log
	set HAVEHELPSVR=N
) else (
        echo source directory %SOURCEDIR%\TEPS\HELPSVR found >>%CANDLE_HOME%\CNPS\logs\ImportAgentTEPS.log
)
  
REM need at least one source directory
if "%HAVECNB%"=="N" (
    if "%HAVECNPS%"=="N" (
        if "%HAVEHELPSVR%"=="N" (
       	echo ERROR: No source directories found >>%CANDLE_HOME%\CNPS\logs\ImportAgentTEPS.log
        exit 2
        )
    )
)

REM copy all files/directories from the source to HELPSVR
if "%HAVEHELPSVR%"=="Y" (
    xcopy /E /Y %SOURCEDIR%\TEPS\HELPSVR %CANDLE_HOME%\HELPSVR >NUL
    IF NOT ERRORLEVEL 0 (
	echo ERROR: file xcopy %SOURCEDIR%\TEPS\HELPSVR %CANDLE_HOME%/HELPSVR failed >>%CANDLE_HOME%\CNPS\logs\ImportAgentTEPS.log
	exit 2
    )
    echo file xcopy %SOURCEDIR%\TEPS\HELPSVR %CANDLE_HOME%\HELPSVR done >>%CANDLE_HOME%\CNPS\logs\ImportAgentTEPS.log
)

REM copy all files/directories from the source to CNPS and CNB
if "%HAVECNPS%"=="Y" (
    xcopy /E /Y %SOURCEDIR%\TEPS\CNPS %CANDLE_HOME%\CNPS >NUL
    IF NOT ERRORLEVEL 0 (
	    echo ERROR: file xcopy %SOURCEDIR%\TEPS\CNPS %CANDLE_HOME%/CNPS failed >>%CANDLE_HOME%\CNPS\logs\ImportAgentTEPS.log
	    exit 2
    )
    echo file xcopy %SOURCEDIR%\TEPS\CNPS %CANDLE_HOME%\CNPS done >>%CANDLE_HOME%\CNPS\logs\ImportAgentTEPS.log
)

if "%HAVECNB%"=="Y" (
xcopy /E /Y %SOURCEDIR%\TEPS\CNB %CANDLE_HOME%\CNB >NUL
IF NOT ERRORLEVEL 0 (
	echo ERROR: file xcopy %SOURCEDIR%\TEPS\CNB %CANDLE_HOME%/CNB failed >>%CANDLE_HOME%\CNPS\logs\ImportAgentTEPS.log
	exit 2
)
echo file xcopy %SOURCEDIR%\TEPS\CNB %CANDLE_HOME%\CNB done >>%CANDLE_HOME%\CNPS\logs\ImportAgentTEPS.log

	REM backup the applet.html file content
	echo =========== applet.html content backup begin ============= >>%CANDLE_HOME%\CNB\applethtml.bak
	type %CANDLE_HOME%\CNB\applet.html >>%CANDLE_HOME%\CNB\applethtml.bak
	echo =========== applet.html content backup end ============= >>%CANDLE_HOME%\CNB\applethtml.bak
	
	REM   check the  inf file
	FOR /F "usebackq" %%f IN (`dir /b %SOURCEDIR%\TEPS\CNB\classes\*.inf`) DO (
		echo  %SOURCEDIR%\TEPS\CNB\classes\%%f found>>%CANDLE_HOME%\CNPS\logs\ImportAgentTEPS.log
		REM process each jar file listed in it
		FOR /F "usebackq tokens=1,2" %%i in (`type %SOURCEDIR%\TEPS\CNB\classes\%%f`) DO (
			REM check existence of the jar file
			if NOT EXIST %SOURCEDIR%\TEPS\CNB\classes\%%i (
				echo  ERROR: %SOURCEDIR%\TEPS\CNB\classes\%%i can not be found. >>%CANDLE_HOME%\CNPS\logs\ImportAgentTEPS.log
				exit 2
			)
			echo  %SOURCEDIR%\TEPS\CNB\classes\%%i found.  >>%CANDLE_HOME%\CNPS\logs\ImportAgentTEPS.log
	
			REM add jar files to the applet.html
			echo ^(^< *PARAM  *NAME *= *CACHE_ARCHIVE  *VALUE *=.*^)^(\^" *^>^)>%TEMP%\sedparm1.tmp
			if NOT ERRORLEVEL 0 (
				echo  ERROR: Can not create jar file %TEMP%\sedparm1.tmp. >>%CANDLE_HOME%\CNPS\logs\ImportAgentTEPS.log
				exit 2
			)
			echo ^$1, %%i^$2 >%TEMP%\sedparm2.tmp
			if NOT ERRORLEVEL 0 (
				echo  ERROR: Can not create jar file %TEMP%\sedparm2.tmp. >>%CANDLE_HOME%\CNPS\logs\ImportAgentTEPS.log
				exit 2
			)
			type %CANDLE_HOME%\CNB\applet.html |cscript //B %CANDLE_HOME%\CNPS\sed.vbs %TEMP%\sedparm1.tmp %TEMP%\sedparm2.tmp >%CANDLE_HOME%\CNB\applet.html.new1
			if NOT ERRORLEVEL 0 (
				echo  ERROR: Can not modify jar file list in the %CANDLE_HOME%\CNB\applet.html. >>%CANDLE_HOME%\CNPS\logs\ImportAgentTEPS.log
				exit 2
			)
			del %TEMP%\sedparm1.tmp
			del %TEMP%\sedparm2.tmp
			echo  %%i added to the CACHE_ARCHIEVE >>%CANDLE_HOME%\CNPS\logs\ImportAgentTEPS.log
	
			REM add version tag to the applet.html
			echo ^(^< *PARAM  *NAME *= *CACHE_VERSION  *VALUE *=.*^)^(\^" *^>^)>%TEMP%\sedparm1.tmp
			if NOT ERRORLEVEL 0 (
				echo  ERROR: Can not create version file %TEMP%\sedparm1.tmp. >>%CANDLE_HOME%\CNPS\logs\ImportAgentTEPS.log
				exit 2
			)
			echo ^$1, %%j^$2 >%TEMP%\sedparm2.tmp
			if NOT ERRORLEVEL 0 (
				echo  ERROR: Can not create version file %TEMP%\sedparm2.tmp. >>%CANDLE_HOME%\CNPS\logs\ImportAgentTEPS.log
				exit 2
			)
			type %CANDLE_HOME%\CNB\applet.html.new1 |cscript //B %CANDLE_HOME%\CNPS\sed.vbs %TEMP%\sedparm1.tmp %TEMP%\sedparm2.tmp >%CANDLE_HOME%\CNB\applet.html.new2
			if NOT ERRORLEVEL 0 (
				echo  ERROR: Can not modify version list in the %CANDLE_HOME%\CNB\applet.html. >>%CANDLE_HOME%\CNPS\logs\ImportAgentTEPS.log
				exit 2
			)
			move /Y %CANDLE_HOME%\CNB\applet.html.new2 %CANDLE_HOME%\CNB\applet.html
			del %TEMP%\sedparm1.tmp
			del %TEMP%\sedparm2.tmp
			del %CANDLE_HOME%\CNB\applet.html.new1
			echo  %%j added to the CACHE_VERSION >>%CANDLE_HOME%\CNPS\logs\ImportAgentTEPS.log
		)
	)
)


exit %ERRORLEVEL%

endlocal
